@@ -5,7 +5,7 @@ class Code(models.Model):
     """
     Registration codes
     """
-    code = models.CharField(max_length=255)
+    code = models.CharField(max_length=255, unique=True)
     is_active = models.BooleanField(default=True)
 
     class Meta:
@@ -13,4 +13,4 @@ class Code(models.Model):
         ordering = ('code',)
 
     def __unicode__(self):
-        return mark_safe(self.code)
\ No newline at end of file
+        return mark_safe(self.code)
